@@ -1,43 +1,7 @@
-/****************************************************************************
-**
-** Copyright (C) 2017 Denis Shienkov <denis.shienkov@gmail.com>
-** Copyright (c) 2020 Andre Hartmann <aha_1980@gmx.de>
-** Copyright (C) 2017 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the QtSerialBus module of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2017 Denis Shienkov <denis.shienkov@gmail.com>
+// Copyright (c) 2020 Andre Hartmann <aha_1980@gmx.de>
+// Copyright (C) 2017 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 #ifndef PEAKCAN_SYMBOLS_P_H
 #define PEAKCAN_SYMBOLS_P_H
@@ -277,14 +241,8 @@
 #define PCAN_TYPE_DNG_SJA_EPP    0x06U  // PCAN-Dongle EPP SJA1000
 
 // Type definitions
-#ifdef Q_OS_MACOS
-#define TPCANLong                quint64
-#else
-#define TPCANLong                quint32
-#endif
-#define TPCANLongToFrameID(a)    static_cast<QCanBusFrame::FrameId>(a)
 #define TPCANHandle              quint16   // Represents a PCAN hardware channel handle
-#define TPCANStatus              TPCANLong // Represents a PCAN status/error code
+#define TPCANStatus              quint32   // Represents a PCAN status/error code
 #define TPCANParameter           quint8    // Represents a PCAN parameter to be read or set
 #define TPCANDevice              quint8    // Represents a PCAN device
 #define TPCANMessageType         quint8    // Represents the type of a PCAN message
@@ -297,7 +255,7 @@
 // Represents a PCAN message
 typedef struct tagTPCANMsg
 {
-    TPCANLong           ID;      // 11/29-bit message identifier
+    quint32             ID;      // 11/29-bit message identifier
     TPCANMessageType    MSGTYPE; // Type of the message
     quint8              LEN;     // Data Length Code of the message (0..8)
     quint8              DATA[8]; // Data of the message (DATA[0]..DATA[7])
@@ -307,7 +265,7 @@ typedef struct tagTPCANMsg
 // Total Microseconds = micros + 1000 * millis + 0xFFFFFFFF * 1000 * millis_overflow
 typedef struct tagTPCANTimestamp
 {
-    TPCANLong   millis;             // Base-value: milliseconds: 0.. 2^32-1
+    quint32     millis;             // Base-value: milliseconds: 0.. 2^32-1
     quint16     millis_overflow;    // Roll-arounds of millis
     quint16     micros;             // Microseconds: 0..999
 } TPCANTimestamp;
@@ -315,7 +273,7 @@ typedef struct tagTPCANTimestamp
 // Represents a PCAN message from a FD capable hardware
 typedef struct tagTPCANMsgFD
 {
-    TPCANLong         ID;       // 11/29-bit message identifier
+    quint32           ID;       // 11/29-bit message identifier
     TPCANMessageType  MSGTYPE;  // Type of the message
     quint8            DLC;      // Data Length Code of the message (0..15)
     quint8            DATA[64]; // Data of the message (DATA[0]..DATA[63])
@@ -342,7 +300,7 @@ typedef struct tagTPCANChannelInformation
     if (!symbolName) \
         return false;
 
-GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_Initialize, TPCANHandle, TPCANBaudrate, TPCANType, TPCANLong, quint16)
+GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_Initialize, TPCANHandle, TPCANBaudrate, TPCANType, quint32, quint16)
 GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_InitializeFD, TPCANHandle, TPCANBitrateFD)
 GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_Uninitialize, TPCANHandle)
 GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_Reset, TPCANHandle)
@@ -351,9 +309,9 @@ GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_Read, TPCANHandle, TPCANMsg *, TPCANTi
 GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_ReadFD, TPCANHandle, TPCANMsgFD *, TPCANTimestampFD *)
 GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_Write, TPCANHandle, TPCANMsg *)
 GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_WriteFD, TPCANHandle, TPCANMsgFD *)
-GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_FilterMessages, TPCANHandle, TPCANLong, TPCANLong, TPCANMode)
-GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_GetValue, TPCANHandle, TPCANParameter, void *, TPCANLong)
-GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_SetValue, TPCANHandle, TPCANParameter, void *, TPCANLong)
+GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_FilterMessages, TPCANHandle, quint32, quint32, TPCANMode)
+GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_GetValue, TPCANHandle, TPCANParameter, void *, quint32)
+GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_SetValue, TPCANHandle, TPCANParameter, void *, quint32)
 GENERATE_SYMBOL_VARIABLE(TPCANStatus, CAN_GetErrorText, TPCANStatus, quint16, char *)
 
 inline bool resolvePeakCanSymbols(QLibrary *pcanLibrary)
